@@ -112,6 +112,31 @@ pn.config.raw_css = ['body { background-color: blue; }']
 pn.Row('Output').servable();
 """
 
+onload_app = """
+import panel as pn
+
+row = pn.Row('Foo')
+
+def onload():
+    row[:] = ['Bar']
+
+pn.state.onload(onload)
+
+row.servable()
+"""
+
+resources_app = """
+import os
+import panel as pn
+
+row = pn.Row()
+
+if os.path.isfile('./app.md'):
+    with open('./app.md') as f:
+        row[:] = [f.read()]
+
+row.servable()
+"""
 
 @pytest.fixture(scope="module")
 def http_serve():
@@ -148,13 +173,22 @@ def http_serve():
         temp_dir.cleanup()
 
 
-def wait_for_app(http_serve, app, page, runtime, wait=True, **kwargs):
+def wait_for_app(http_serve, app, page, runtime, wait=True, resources=None, **kwargs):
     app_path = http_serve(app)
 
+    resource_paths = []
+    for resource in (resources or []):
+        resource_path = app_path.parent / pathlib.Path(resource).name
+        try:
+            shutil.copy(resource, resource_path)
+        except shutil.SameFileError:
+            pass
+        resource_paths.append(resource_path)
+
     convert_apps(
         [app_path], app_path.parent, runtime=runtime, build_pwa=False,
         prerender=False, panel_version='local', inline=True,
-        local_prefix=HTTP_URL, **kwargs
+        local_prefix=HTTP_URL, resources=resource_paths, **kwargs
     )
 
     msgs = []
@@ -250,9 +284,9 @@ def test_pyodide_test_convert_csv_app(http_serve, page, runtime, http_patch):
     expected_titles = ['index', 'date', 'Temperature', 'Humidity', 'Light', 'CO2', 'HumidityRatio', 'Occupancy']
 
     titles = page.locator('.tabulator-col-title')
-    expect(titles).to_have_count(1 + len(expected_titles), timeout=60 * 1000)
+    expect(titles).to_have_count(2 + len(expected_titles), timeout=60 * 1000)
     titles = titles.all_text_contents()
-    assert titles[1:] == expected_titles
+    assert titles[1:-1] == expected_titles
 
     assert [msg for msg in msgs if msg.type == 'error' and 'favicon' not in msg.location['url']] == []
 
@@ -264,3 +298,24 @@ def test_pyodide_test_convert_png_app(http_serve, page, runtime):
     expect(page.locator('img')).to_have_count(1)
 
     assert [msg for msg in msgs if msg.type == 'error' and 'favicon' not in msg.location['url']] == []
+
+
+@pytest.mark.parametrize('runtime', ['pyodide', 'pyodide-worker'])
+def test_pyodide_test_convert_onload_app(http_serve, page, runtime):
+    msgs = wait_for_app(http_serve, onload_app, page, runtime)
+
+    expect(page.locator('.markdown')).to_have_text('Bar')
+
+    assert [msg for msg in msgs if msg.type == 'error' and 'favicon' not in msg.location['url']] == []
+
+
+@pytest.mark.parametrize('runtime', ['pyodide', 'pyodide-worker'])
+def test_pyodide_test_convert_resources_app(http_serve, page, runtime):
+    resource_path = pathlib.Path(__file__).parent / 'app.md'
+    msgs = wait_for_app(
+        http_serve, resources_app, page, runtime, resources=[resource_path]
+    )
+
+    expect(page.locator('.markdown')).to_have_text(resource_path.read_text().replace('```', '').replace('{pyodide}', ''))
+
+    assert [msg for msg in msgs if msg.type == 'error' and 'favicon' not in msg.location['url']] == []
